@@ -1,43 +1,44 @@
-from .base import Base
+from .base import ObjectBase
 
 
-class Customer(Base):
+class Customer(ObjectBase):
     @classmethod
     def get_resource_class(cls, client):
         from ..resources.customers import Customers
+
         return Customers(client)
 
     @property
     def id(self):
-        return self._get_property('id')
+        return self._get_property("id")
 
     @property
     def name(self):
-        return self._get_property('name')
+        return self._get_property("name")
 
     @property
     def email(self):
-        return self._get_property('email')
+        return self._get_property("email")
 
     @property
     def locale(self):
-        return self._get_property('locale')
+        return self._get_property("locale")
 
     @property
     def metadata(self):
-        return self._get_property('metadata')
+        return self._get_property("metadata")
 
     @property
     def mode(self):
-        return self._get_property('mode')
+        return self._get_property("mode")
 
     @property
     def resource(self):
-        return self._get_property('resource')
+        return self._get_property("resource")
 
     @property
     def created_at(self):
-        return self._get_property('createdAt')
+        return self._get_property("createdAt")
 
     @property
     def subscriptions(self):
