@@ -1,7 +1,7 @@
-from .base import Base
+from .base import ObjectBase
 
 
-class Organization(Base):
+class Organization(ObjectBase):
     @classmethod
     def get_resource_class(cls, client):
         from ..resources.organizations import Organizations
