@@ -1,42 +1,42 @@
-from .base import Base
+from .base import ObjectBase
 from .list import List
 from .order_line import OrderLine
 
 
-class Shipment(Base):
+class Shipment(ObjectBase):
     @property
     def resource(self):
-        return self._get_property('resource')
+        return self._get_property("resource")
 
     @property
     def id(self):
-        return self._get_property('id')
+        return self._get_property("id")
 
     @property
     def order_id(self):
-        return self._get_property('orderId')
+        return self._get_property("orderId")
 
     @property
     def created_at(self):
-        return self._get_property('createdAt')
+        return self._get_property("createdAt")
 
     @property
     def tracking(self):
-        return self._get_property('tracking')
+        return self._get_property("tracking")
 
     @property
     def tracking_url(self):
-        return self.tracking['url'] if self.has_tracking_url() else None
+        return self.tracking["url"] if self.has_tracking_url() else None
 
     @property
     def lines(self):
         """Return the order lines of this shipment."""
-        lines = self._get_property('lines') or []
+        lines = self._get_property("lines") or []
         result = {
-            '_embedded': {
-                'lines': lines,
+            "_embedded": {
+                "lines": lines,
             },
-            'count': len(lines),
+            "count": len(lines),
         }
         return List(result, OrderLine, self.client)
 
@@ -51,4 +51,4 @@ class Shipment(Base):
         return self.tracking is not None
 
     def has_tracking_url(self):
-        return self.has_tracking() and self.tracking['url'] is not None
+        return self.has_tracking() and self.tracking["url"] is not None
