@@ -1,9 +1,9 @@
 from ..error import IdentifierError
 from ..objects.mandate import Mandate
-from .base import Base
+from .base import ResourceBase
 
 
-class CustomerMandates(Base):
+class CustomerMandates(ResourceBase):
     RESOURCE_ID_PREFIX = "mdt_"
     customer_id = None
 
@@ -13,14 +13,12 @@ class CustomerMandates(Base):
     def get(self, mandate_id, **params):
         if not mandate_id or not mandate_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
-                "Invalid mandate ID: '{id}'. A mandate ID should start with '{prefix}'.".format(
-                    id=mandate_id, prefix=self.RESOURCE_ID_PREFIX
-                )
+                f"Invalid mandate ID: '{mandate_id}'. A mandate ID should start with '{self.RESOURCE_ID_PREFIX}'."
             )
         return super().get(mandate_id, **params)
 
     def get_resource_name(self):
-        return "customers/{id}/mandates".format(id=self.customer_id)
+        return f"customers/{self.customer_id}/mandates"
 
     def with_parent_id(self, customer_id):
         self.customer_id = customer_id
