@@ -1,9 +1,9 @@
 from ..error import IdentifierError
 from ..objects.invoice import Invoice
-from .base import Base
+from .base import ResourceBase
 
 
-class Invoices(Base):
+class Invoices(ResourceBase):
     RESOURCE_ID_PREFIX = "inv_"
 
     def get_resource_object(self, result):
@@ -12,8 +12,6 @@ class Invoices(Base):
     def get(self, invoice_id, **params):
         if not invoice_id or not invoice_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
-                "Invalid invoice ID: '{id}'. A invoice ID should start with '{prefix}'.".format(
-                    id=invoice_id, prefix=self.RESOURCE_ID_PREFIX
-                )
+                f"Invalid invoice ID: '{invoice_id}'. An invoice ID should start with '{self.RESOURCE_ID_PREFIX}'."
             )
         return super().get(invoice_id, **params)
