@@ -1,17 +1,15 @@
 from ..error import IdentifierError
 from ..objects.onboarding import Onboarding as OnboardingObject
-from .base import Base
+from .base import ResourceBase
 
 
-class Onboarding(Base):
+class Onboarding(ResourceBase):
     def get_resource_object(self, result):
         return OnboardingObject(result, self.client)
 
     def get(self, onboarding_id, **params):
         if not onboarding_id or not onboarding_id == "me":
-            raise IdentifierError(
-                "Invalid onboarding ID: '{id}'. A onboarding ID should be 'me'.".format(id=onboarding_id)
-            )
+            raise IdentifierError(f"Invalid onboarding ID: '{onboarding_id}'. An onboarding ID should be 'me'.")
         return super().get(onboarding_id, **params)
 
     def create(self, resource_id, data=None, **params):
