@@ -5,7 +5,7 @@ class ProfileChargebacks(Chargebacks):
     profile_id = None
 
     def get_resource_name(self):
-        return "chargebacks?profileId={id}".format(id=self.profile_id)
+        return f"chargebacks?profileId={self.profile_id}"
 
     def with_parent_id(self, profile_id):
         self.profile_id = profile_id
